pub enum ErrorNorm {
Mean,
Max,
}Expand description
Strategy used to reduce componentwise output errors to one scalar.
For scalar outputs, both variants are equivalent.
For vector, matrix, or array outputs, this determines how local integration error is converted to the scalar value used by the adaptive controller.
Variants