LineSegment

Struct LineSegment 

pub struct LineSegment<I> { /* private fields */ }
Straight contour piece between two points.

LineSegment is generic over the input type and can represent both real intervals and complex line segments.

Implementations

Source

impl<C> LineSegment<C>

pub fn indent_around_point<F>( &self, pole: F::Complex, radius: F, side: IndentSide, tolerance: F, ) -> Option<Vec<ContourSegment<F>>>
where F: ComplexScalar<Complex = C> + FromPrimitive, C: ComplexField<RealField = F> + Copy,

Source

impl<I> LineSegment<I>

pub fn new(start: I, end: I) -> Self

Creates a new line segment from start to end.

pub fn start(&self) -> I
where I: Copy,

pub fn end(&self) -> I
where I: Copy,

pub fn reversed(self) -> Self
where I: Copy,