IntegrableFloat

Trait IntegrableFloat 

pub trait IntegrableFloat:
    ComplexScalar
    + Float
    + FromPrimitive
    + AddAssign
    + SubAssign
    + TrellisFloat
    + Send
    + Sync
    + 'static { }
Floating-point type supported by the integration routines.

This trait bundles together the numerical functionality required by the integration algorithms. It is primarily an implementation detail used to restrict the supported scalar types.

Currently the crate supports:

  • f32
  • f64

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntegrableFloat for f32

Source

impl IntegrableFloat for f64

Implementors