ErrorNorm

Enum ErrorNorm 

pub enum ErrorNorm {
    Mean,
    Max,
}
Strategy used to reduce componentwise output errors to one scalar.

For scalar outputs, both variants are equivalent.

For vector, matrix, or array outputs, this determines how local integration error is converted to the scalar value used by the adaptive controller.

Variants



Mean

Use the arithmetic mean of component magnitudes.



Max

Use the largest component magnitude.