pub trait IntegrableFloat:
ComplexScalar
+ Float
+ FromPrimitive
+ AddAssign
+ SubAssign
+ TrellisFloat
+ Send
+ Sync
+ 'static { }Expand description
Floating-point type supported by the integration routines.
This trait bundles together the numerical functionality required by the integration algorithms. It is primarily an implementation detail used to restrict the supported scalar types.
Currently the crate supports:
f32f64
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".